@@ -22,10 +22,10 @@ def to_text(path):
 
     if spawn.find_executable("pdftotext"):  # shutil.which('pdftotext'):
         out, err = subprocess.Popen(
-            ["pdftotext", '-layout', '-enc', 'UTF-8', path, '-'], stdout=subprocess.PIPE
+            ["pdftotext", "-layout", "-enc", "UTF-8", path, "-"], stdout=subprocess.PIPE
         ).communicate()
         return out
     else:
         raise EnvironmentError(
-            'pdftotext not installed. Can be downloaded from https://poppler.freedesktop.org/'
+            "pdftotext not installed. Can be downloaded from https://poppler.freedesktop.org/"
         )
